==> bokain_models-0.0.135.tar.gz: lib/src/customer.dart <==
library customer;

import 'model.dart';
import 'package:angular2/common.dart';
import 'package:fo_components/fo_components.dart';


class Customer extends Model
{
  Customer()
  {
  }

  Customer.parse(Map<String, dynamic> data) : super.parse(data)
  {
    id = data["id"];
    addedBy = data["added_by"];
    belongsTo = data["belongs_to"];
    city = data["city"];
    commentsExternal = data["comments_external"];
    commentsInternal = data["comments_internal"];
    consultationId = data["consultation_id"];
    country = data["country"];
    email = data["email"];
    emailShop = data["email_shop"];
    firstname = data["firstname"];
    lastname = data["lastname"];
    phone = data["phone"];
    postalCode = data["postal_code"];
    preferredLanguage = data["preferred_language"];
    skinType = data["skin_type"];
    socialNumber = data["social_number"];
    status = data["status"];
    street = data["street"];
  }

  @override
  Map<String, dynamic> get properties
  {
    Map<String, dynamic> data = new Map();
    data["added_by"] = addedBy;
    data["belongs_to"] = belongsTo;
    data["city"] = city;
    data["comments_external"] = commentsExternal;
    data["comments_internal"] = commentsInternal;
    data["consultation_id"] = consultationId;
    data["country"] = country;
    data["email"] = email;
    data["email_shop"] = emailShop;
    data["firstname"] = firstname;
    data["lastname"] = lastname;
    data["phone"] = phone;
    data["postal_code"] = postalCode;
    data["preferred_language"] = preferredLanguage;
    data["skin_type"] = skinType;
    data["social_number"] = socialNumber;
    data["status"] = status;
    data["street"] = street;

    return data;
  }

  @override
  List<String> get uniqueFields => ["email", "email_shop", "phone", "social_number"];

  static Map<String, dynamic> get controlsConfig => _controlsConfig;

  static Map<String, dynamic> _controlsConfig =
  {
    "email":[null, Validators.compose([Validators.required, Validators.maxLength(100)])],
    "phone":[null, Validators.compose([Validators.required, FoValidators.isPhoneNumber, Validators.maxLength(32)])],
    "social_number":[null, Validators.compose([Validators.required, Validators.minLength(12), Validators.maxLength(12), FoValidators.isNumeric])],
    "firstname":[null, Validators.compose([Validators.required, FoValidators.isAlpha, Validators.maxLength(64)])],
    "lastname":[null, Validators.compose([Validators.required, FoValidators.isAlpha, Validators.maxLength(64)])],
    "street":[null, Validators.compose([Validators.required, Validators.minLength(4), Validators.maxLength(64)])],
    "postal_code":[null, Validators.compose([Validators.required, FoValidators.isAlphaNumeric, Validators.minLength(2), Validators.maxLength(20)])],
    "city":[null, Validators.compose([Validators.required, Validators.maxLength(64)])],
    "comments_internal" : [null, Validators.maxLength(8000)],
    "comments_external" : [null, Validators.maxLength(8000)],
    "country" : null,
    "skin_type" : null,
    "belongs_to" : null,
  };


  String belongsTo;
  String commentsExternal;
  String commentsInternal;
  String addedBy;
  String consultationId;
  String city;
  String country;
  String email;
  String emailShop;
  String firstname;
  String lastname;
  String phone;
  String postalCode;
  String preferredLanguage = "sv";
  String skinType;
  String socialNumber;
  String street;
}

==> bokain_models-0.0.136.tar.gz: lib/src/customer.dart <==
library customer;

import 'model.dart';
import 'package:angular2/common.dart';
import 'package:fo_components/fo_components.dart';


class Customer extends Model
{
  Customer()
  {
  }

  Customer.parse(Map<String, dynamic> data) : super.parse(data)
  {
    id = data["id"];
    addedBy = data["added_by"];
    belongsTo = data["belongs_to"];
    city = data["city"];
    commentsExternal = data["comments_external"];
    commentsInternal = data["comments_internal"];
    consultationId = data["consultation_id"];
    country = data["country"];
    email = data["email"];
    emailShop = data["email_shop"];
    firstname = data["firstname"];
    lastname = data["lastname"];
    phone = data["phone"];
    postalCode = data["postal_code"];
    preferredLanguage = data["preferred_language"];
    skinType = data["skin_type"];
    socialNumber = data["social_number"];
    status = data["status"];
    street = data["street"];
  }

  @override
  Map<String, dynamic> get properties
  {
    Map<String, dynamic> data = new Map();
    data["added_by"] = addedBy;
    data["belongs_to"] = belongsTo;
    data["city"] = city;
    data["comments_external"] = commentsExternal;
    data["comments_internal"] = commentsInternal;
    data["consultation_id"] = consultationId;
    data["country"] = country;
    data["email"] = email;
    data["email_shop"] = emailShop;
    data["firstname"] = firstname;
    data["lastname"] = lastname;
    data["phone"] = phone;
    data["postal_code"] = postalCode;
    data["preferred_language"] = preferredLanguage;
    data["skin_type"] = skinType;
    data["social_number"] = socialNumber;
    data["status"] = status;
    data["street"] = street;

    return data;
  }

  @override
  List<String> get uniqueFields => ["email", "email_shop", "phone", "social_number"];

  static Map<String, dynamic> get controlsConfig => _controlsConfig;

  static Map<String, dynamic> _controlsConfig =
  {
    "email":[null, Validators.compose([Validators.required, Validators.maxLength(100)])],
    "phone":[null, Validators.compose([Validators.required, FoValidators.isPhoneNumber, Validators.maxLength(32)])],
    "social_number":[null, Validators.compose([Validators.required, Validators.minLength(12), Validators.maxLength(12), FoValidators.isNumeric])],
    "firstname":[null, Validators.compose([Validators.required, FoValidators.isName, Validators.maxLength(64)])],
    "lastname":[null, Validators.compose([Validators.required, FoValidators.isName, Validators.maxLength(64)])],
    "street":[null, Validators.compose([Validators.required, Validators.minLength(4), Validators.maxLength(64)])],
    "postal_code":[null, Validators.compose([Validators.required, FoValidators.isAlphaNumeric, Validators.minLength(2), Validators.maxLength(20)])],
    "city":[null, Validators.compose([Validators.required, Validators.maxLength(64)])],
    "comments_internal" : [null, Validators.maxLength(8000)],
    "comments_external" : [null, Validators.maxLength(8000)],
    "country" : null,
    "skin_type" : null,
    "belongs_to" : null,
  };


  String belongsTo;
  String commentsExternal;
  String commentsInternal;
  String addedBy;
  String consultationId;
  String city;
  String country;
  String email;
  String emailShop;
  String firstname;
  String lastname;
  String phone;
  String postalCode;
  String preferredLanguage = "sv";
  String skinType;
  String socialNumber;
  String street;
}
